@@ -325,6 +325,7 @@ extract_track_foreach_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *i
                       COLUMN_DETAILS, &track,
                       -1);
   if (extract) {
+    track->iter = *iter;
     pending = g_list_append (pending, track);
     ++total_extracting;
     total_duration += track->duration;
@@ -454,7 +455,7 @@ show_finished_dialog (void)
                                    _("The tracks have been copied successfully."));
   /* If we eject when finished, eject now, otherwise add a button */
   if (eject_finished) {
-    eject_cdrom (device, GTK_WINDOW (main_window));
+    nautilus_burn_drive_eject (drive);
   } else {
     gtk_dialog_add_buttons (GTK_DIALOG (dialog), _("_Eject"), 2, NULL);
   }
@@ -471,7 +472,7 @@ show_finished_dialog (void)
     g_spawn_command_line_async (command, NULL);
     g_free (command);
   } else if (result == 2) {
-    eject_cdrom (device, GTK_WINDOW (main_window));
+    nautilus_burn_drive_eject (drive);
   }
   g_free (base);
 }
@@ -482,7 +483,9 @@ show_finished_dialog (void)
 static void
 on_completion_cb (SjExtractor *extractor, gpointer data)
 {
-  /* TODO: uncheck the relevant check box */
+  /* Uncheck the Extract check box */
+  gtk_list_store_set (track_store, &track->iter, COLUMN_EXTRACT, FALSE, -1);
+
   if (pending == NULL) {
     gtk_widget_hide (progress_dialog);
     show_finished_dialog ();
@@ -518,8 +521,8 @@ on_error_cb (SjExtractor *extractor, GError *error, gpointer data)
 
   gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
-  
-  g_error_free (error);
+
+  /* No need to free the error passed in */
   cleanup ();
   extracting = FALSE;
 }
@@ -576,12 +579,12 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
     genre_combo = glade_xml_get_widget (glade, "genre_combo");
     track_listview = glade_xml_get_widget (glade, "track_listview");
     
-	extract_menuitem = glade_xml_get_widget (glade, "extract_menuitem");
-	reread_menuitem = glade_xml_get_widget (glade, "re-read");
-	select_all_menuitem = glade_xml_get_widget (glade, "select_all");
-	deselect_all_menuitem = glade_xml_get_widget (glade, "deselect_all");
-	
-	/* TODO : this callback should be in the glade file */
+    extract_menuitem = glade_xml_get_widget (glade, "extract_menuitem");
+    reread_menuitem = glade_xml_get_widget (glade, "re-read");
+    select_all_menuitem = glade_xml_get_widget (glade, "select_all");
+    deselect_all_menuitem = glade_xml_get_widget (glade, "deselect_all");
+    
+    /* TODO : this callback should be in the glade file */
     g_signal_connect (progress_dialog, "delete-event", G_CALLBACK (on_progress_cancel_clicked), NULL);
 
     initialised = TRUE;
@@ -630,11 +633,13 @@ on_extract_activate (GtkWidget *button, gpointer user_data)
 static char*
 sanitize_path (char* s)
 {
-  /* Replace path seperators with whitespace */
-  g_strdelimit (s, "/", ' ');
+  /* Replace path seperators with a hyphen */
+  g_strdelimit (s, "/", '-');
   if (strip_chars) {
-    /* Mangle all weird characters to whitespace */
-    g_strdelimit (s, "\\*?&!:\'\"$()`|>{}", ' ');
+    /* Replace separators with a hyphen */
+    g_strdelimit (s, "\\:|", '-');
+    /* Replace all other weird characters to whitespace */
+    g_strdelimit (s, "*?&!\'\"$()`>{}", ' ');
     /* Replace all whitespace with underscores */
     /* TODO: I'd like this to compress whitespace aswell */
     g_strdelimit (s, "\t ", '_');
